@@ -1,5 +1,6 @@
 import re
 
+from bs4.element import Tag
 
 def strcompile(exp):
     if isinstance(exp, str):
@@ -9,6 +10,10 @@ def strcompile(exp):
 
 
 def extgroup(exp, target, asdict=False):
+
+    if isinstance(target, Tag):
+        target = target.get_text()
+
     regex = strcompile(exp)
     if g := regex.search(target):
         if asdict:
